/*
 * File:     wb_gdi.h
 * Purpose:  Declaration of various graphics objects - fonts, pens, icons etc.
 *
 *                       wxWindows 1.50
 * Copyright (c) 1993 Artificial Intelligence Applications Institute,
 *                   The University of Edinburgh
 *
 *                     Author: Julian Smart
 *                       Date: 7-9-93
 *
 * Permission to use, copy, modify, and distribute this software and its
 * documentation for any purpose is hereby granted without fee, provided
 * that the above copyright notice, author statement and this permission
 * notice appear in all copies of this software and related documentation.
 *
 * THE SOFTWARE IS PROVIDED "AS-IS" AND WITHOUT WARRANTY OF ANY KIND, EXPRESS,
 * IMPLIED OR OTHERWISE, INCLUDING WITHOUT LIMITATION, ANY WARRANTY OF
 * MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE.
 *
 * IN NO EVENT SHALL THE ARTIFICIAL INTELLIGENCE APPLICATIONS INSTITUTE OR THE
 * UNIVERSITY OF EDINBURGH BE LIABLE FOR ANY SPECIAL, INCIDENTAL, INDIRECT OR
 * CONSEQUENTIAL DAMAGES OF ANY KIND, OR ANY DAMAGES WHATSOEVER RESULTING FROM
 * LOSS OF USE, DATA OR PROFITS, WHETHER OR NOT ADVISED OF THE POSSIBILITY OF
 * DAMAGE, AND ON ANY THEORY OF LIABILITY, ARISING OUT OF OR IN CONNECTION WITH
 * THE USE OR PERFORMANCE OF THIS SOFTWARE.
 */


#ifndef wxb_gdih
#define wxb_gdih

// Standard cursors
#define wxCURSOR_ARROW           1
#define wxCURSOR_BULLSEYE        2
#define wxCURSOR_CHAR            3
#define wxCURSOR_CROSS           4
#define wxCURSOR_HAND            5
#define wxCURSOR_IBEAM           6
#define wxCURSOR_LEFT_BUTTON     7
#define wxCURSOR_MAGNIFIER       8
#define wxCURSOR_MIDDLE_BUTTON   9
#define wxCURSOR_NO_ENTRY       10
#define wxCURSOR_PAINT_BRUSH    11
#define wxCURSOR_PENCIL         12
#define wxCURSOR_POINT_LEFT     13
#define wxCURSOR_POINT_RIGHT    14
#define wxCURSOR_QUESTION_ARROW 15
#define wxCURSOR_RIGHT_BUTTON   16
#define wxCURSOR_SIZENESW       17
#define wxCURSOR_SIZENS         18
#define wxCURSOR_SIZENWSE       19
#define wxCURSOR_SIZEWE         20
#define wxCURSOR_SIZING         21
#define wxCURSOR_SPRAYCAN       22
#define wxCURSOR_WAIT           23
#define wxCURSOR_WATCH          24

// Font
class wxFont;
class wxbFont: public wxObject
{
 public:
  Bool temporary;   // If TRUE, the pointer to the actual font
                    // is temporary and SHOULD NOT BE DELETED by
                    // destructor
  int point_size;
  int family;
  int style;
  int weight;
  Bool underlined;
  wxbFont(void);
  wxbFont(int PointSize, int Family, int Style, int Weight, Bool underline = FALSE);
  ~wxbFont(void);

  inline int GetPointSize(void) { return point_size; }
  inline int GetFamily(void) { return family; }
  inline int GetStyle(void) { return style; }
  inline int GetWeight(void) { return weight; }
  inline Bool GetUnderlined(void) { return underlined; }
};

// Colour
class wxColour: public wxObject
{
 public:
#ifdef wx_x
  unsigned long pixel;
#endif
  char red;
  char blue;
  char green;

  wxColour(char r, char b, char g);
  wxColour(char *col);

  virtual void Set(char r, char b, char g);
  virtual void Get(char *r, char *b, char *g);

  virtual char Red(void);
  virtual char Green(void);
  virtual char Blue(void);
};

#define wxColor wxColour

class wxColourMap;
class wxbColourMap: public wxObject
{
 public:
  wxbColourMap(void);
  ~wxbColourMap(void);
};

// Point
class wxPoint: public wxObject
{
 public:
  float x;
  float y;
  wxPoint(void);
  wxPoint(float the_x, float the_y);
};

// Pen
class wxPen;
class wxbPen: public wxObject
{
 public:
  int width;
  int style;
  wxColour *colour;

  wxbPen(void);
  wxbPen(wxColour& col, int width, int style);
  wxbPen(char *col, int width, int style);
  ~wxbPen(void);

  virtual void SetColour(wxColour& col) = 0;
  virtual void SetColour(char *col) = 0;
  virtual void SetColour(char r, char g, char b) = 0;

  virtual void SetWidth(int width) = 0;
  virtual void SetStyle(int style) = 0;

  virtual wxColour &GetColour(void);
  virtual int GetWidth(void);
  virtual int GetStyle(void);
};

// Brush
class wxBrush;
class wxbBrush: public wxObject
{
 public:
  int style;
  wxColour *colour;

  wxbBrush(void);
  wxbBrush(wxColour& col, int style);
  wxbBrush(char *col, int style);
  ~wxbBrush(void);

  virtual void SetColour(wxColour& col) = 0;
  virtual void SetColour(char *col) = 0;
  virtual void SetColour(char r, char g, char b) = 0;
  virtual void SetStyle(int style) = 0;
  virtual wxColour &GetColour(void);
  virtual int GetStyle(void);
};

// Icon
class wxIcon;
class wxbIcon: public wxObject
{
 public:
  wxbIcon(char bits[], int width, int height);
  wxbIcon(char *name);
  ~wxbIcon(void);
};

// Cursor
class wxCursor;
class wxbCursor: public wxObject
{
 public:
  wxbCursor(char bits[], int width, int height);
  wxbCursor(char *name);
  wxbCursor(int cursor_type);
  ~wxbCursor(void);
};

// Bitmap
class wxBitmap;
class wxbBitmap: public wxObject
{
 public:
  int width;
  int height;
  int depth;
  Bool ok;

  wxbBitmap(char bits[], int width, int height, int depth = 1);
  wxbBitmap(char *name);
  // If depth is omitted, will create a bitmap compatible with the display
  wxbBitmap(int width, int height, int depth = -1);
  ~wxbBitmap(void);

  inline Bool Ok(void) { return ok; }
  inline int GetWidth(void) { return width; }
  inline int GetHeight(void) { return height; }
  inline int GetDepth(void) { return depth; }
};

// Management of pens, brushes and fonts
class wxPenList: public wxList
{
 public:
  wxPenList(void)
    { }
  ~wxPenList(void);
  void AddPen(wxPen *pen);
  void RemovePen(wxPen *pen);
  wxPen *FindOrCreatePen(wxColour *colour, int width, int style);
  wxPen *FindOrCreatePen(char *colour, int width, int style);
};

class wxBrushList: public wxList
{
 public:
  wxBrushList(void)
    { }
  ~wxBrushList(void);
  void AddBrush(wxBrush *brush);
  void RemoveBrush(wxBrush *brush);
  wxBrush *FindOrCreateBrush(wxColour *colour, int style);
  wxBrush *FindOrCreateBrush(char *colour, int style);
};

class wxColourDatabase: public wxList
{
 public:
  wxColourDatabase(int type);
  wxColour *FindColour(char *colour);
  char *FindName(wxColour& colour);
  void Initialize(void);
};

class wxGDIList: public wxList
{
 public:
   wxGDIList(void);
  ~wxGDIList(void);
};

// Lists of GDI objects
extern wxPenList   *wxThePenList;
extern wxBrushList *wxTheBrushList;
extern wxGDIList   *wxTheIconList;
extern wxGDIList   *wxTheFontList;
extern wxGDIList   *wxTheBitmapList;

// Stock objects
extern wxFont *wxNORMAL_FONT;
extern wxFont *wxSMALL_FONT;
extern wxFont *wxITALIC_FONT;
extern wxFont *wxSWISS_FONT;
extern wxPen *wxRED_PEN;
extern wxPen *wxCYAN_PEN;
extern wxPen *wxGREEN_PEN;
extern wxPen *wxBLACK_PEN;
extern wxPen *wxTRANSPARENT_PEN;
extern wxPen *wxBLACK_DASHED_PEN;

extern wxBrush *wxBLUE_BRUSH;
extern wxBrush *wxGREEN_BRUSH;
extern wxBrush *wxWHITE_BRUSH;
extern wxBrush *wxBLACK_BRUSH;
extern wxBrush *wxGREY_BRUSH;
extern wxBrush *wxMEDIUM_GREY_BRUSH;
extern wxBrush *wxLIGHT_GREY_BRUSH;
extern wxBrush *wxTRANSPARENT_BRUSH;
extern wxBrush *wxCYAN_BRUSH;
extern wxBrush *wxRED_BRUSH;

extern wxColour *wxBLACK;
extern wxColour *wxWHITE;
extern wxColour *wxRED;
extern wxColour *wxBLUE;
extern wxColour *wxGREEN;
extern wxColour *wxCYAN;
extern wxColour *wxLIGHT_GREY;

// Stock cursors types
extern wxCursor *wxSTANDARD_CURSOR;
extern wxCursor *wxHOURGLASS_CURSOR;
extern wxCursor *wxCROSS_CURSOR;

extern wxColourDatabase *wxTheColourDatabase;
extern void wxInitializeStockObjects(void);

extern Bool wxColourDisplay(void);

// Returns depth of screen
extern int wxDisplayDepth(void);

extern void wxDisplaySize(int *width, int *height);

extern void wxSetCursor(wxCursor *cursor);

#endif // wxb_gdih
