/*
 * File:     wx_frame.h
 * Purpose:  wxFrame declaration (X version)
 *
 *                       wxWindows 1.50
 * Copyright (c) 1993 Artificial Intelligence Applications Institute,
 *                   The University of Edinburgh
 *
 *                     Author: Julian Smart
 *                       Date: 7-9-93
 *
 * Permission to use, copy, modify, and distribute this software and its
 * documentation for any purpose is hereby granted without fee, provided
 * that the above copyright notice, author statement and this permission
 * notice appear in all copies of this software and related documentation.
 *
 * THE SOFTWARE IS PROVIDED "AS-IS" AND WITHOUT WARRANTY OF ANY KIND, EXPRESS,
 * IMPLIED OR OTHERWISE, INCLUDING WITHOUT LIMITATION, ANY WARRANTY OF
 * MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE.
 *
 * IN NO EVENT SHALL THE ARTIFICIAL INTELLIGENCE APPLICATIONS INSTITUTE OR THE
 * UNIVERSITY OF EDINBURGH BE LIABLE FOR ANY SPECIAL, INCIDENTAL, INDIRECT OR
 * CONSEQUENTIAL DAMAGES OF ANY KIND, OR ANY DAMAGES WHATSOEVER RESULTING FROM
 * LOSS OF USE, DATA OR PROFITS, WHETHER OR NOT ADVISED OF THE POSSIBILITY OF
 * DAMAGE, AND ON ANY THEORY OF LIABILITY, ARISING OUT OF OR IN CONNECTION WITH
 * THE USE OR PERFORMANCE OF THIS SOFTWARE.
 */

#ifndef wx_frameh
#define wx_frameh

#include "common.h"
#include "wb_frame.h"

#ifdef wx_xview
#include <xview/frame.h>
#endif

#ifdef wx_motif
#include <Xm/Xm.h>
#endif

class wxPanel;
class wxMenuBar;

class wxStatusWnd;
class wxFrame: public wxbFrame
{
  char *frameTitle;
 public:
  // Store current size so we can ignore resize if only
  // a reposition!
  int lastWidth;
  int lastHeight;

#ifdef wx_motif
  Widget frameShell;
  Widget frameWidget;
  Widget workArea;
  Widget clientArea;
  Widget menuBarWidget;
  Widget statusLineWidget;
  Widget statusTextWidget;
  Widget GetMenuBarWidget(void);
  Bool PreResize(void);
#endif
#ifdef wx_xview
  wxPanel *menu_bar_panel;
  int y_offset;
#endif

  wxFrame(void);
  wxFrame(wxFrame *parent, char *title,
          int x=-1, int y=-1, int width=-1, int height=-1,
          int type = wxSDI | wxDEFAULT_FRAME);

  ~wxFrame(void);

  virtual Bool Create(wxFrame *parent, char *title,
          int x=-1, int y=-1, int width=-1, int height=-1,
          int type = wxSDI | wxDEFAULT_FRAME);

  void SetClientSize(int width, int height);
  void GetClientSize(int *width, int *height);

  void GetSize(int *width, int *height);
  void GetPosition(int *x, int *y);
  void SetSize(int x, int y, int width, int height);
  void Show(Bool show);

  // Set menu bar
  void SetMenuBar(wxMenuBar *menu_bar);

  // Set title
  char *GetTitle(void);
  void SetTitle(char *title);

  // Set icon
  void SetIcon(wxIcon *icon);

  // Create status line
  void CreateStatusLine(void);

  // Set status line text
  void SetStatusText(char *text);

  // Fit frame around subwindows
  void Fit(void);

  // Iconize
  void Iconize(Bool iconize);
  Bool Iconized(void);
  // Windos 3.x maximize/restore
  void Maximize(Bool maximize);

  void LoadAccelerators(char *table);
};
#endif // wx_frameh
