/*
 * File:     wx_gdi.h
 * Purpose:  Declaration of various graphics objects - fonts, pens, icons etc.
 *
 *                       wxWindows 1.50
 * Copyright (c) 1993 Artificial Intelligence Applications Institute,
 *                   The University of Edinburgh
 *
 *                     Author: Julian Smart
 *                       Date: 7-9-93
 *
 * Permission to use, copy, modify, and distribute this software and its
 * documentation for any purpose is hereby granted without fee, provided
 * that the above copyright notice, author statement and this permission
 * notice appear in all copies of this software and related documentation.
 *
 * THE SOFTWARE IS PROVIDED "AS-IS" AND WITHOUT WARRANTY OF ANY KIND, EXPRESS,
 * IMPLIED OR OTHERWISE, INCLUDING WITHOUT LIMITATION, ANY WARRANTY OF
 * MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE.
 *
 * IN NO EVENT SHALL THE ARTIFICIAL INTELLIGENCE APPLICATIONS INSTITUTE OR THE
 * UNIVERSITY OF EDINBURGH BE LIABLE FOR ANY SPECIAL, INCIDENTAL, INDIRECT OR
 * CONSEQUENTIAL DAMAGES OF ANY KIND, OR ANY DAMAGES WHATSOEVER RESULTING FROM
 * LOSS OF USE, DATA OR PROFITS, WHETHER OR NOT ADVISED OF THE POSSIBILITY OF
 * DAMAGE, AND ON ANY THEORY OF LIABILITY, ARISING OUT OF OR IN CONNECTION WITH
 * THE USE OR PERFORMANCE OF THIS SOFTWARE.
 */


#ifndef wx_gdih
#define wx_gdih

#include "wb_gdi.h"

#ifdef wx_motif
#include <Xm/Xm.h>
#endif

#ifdef wx_xview
#include <xview/font.h>
#include <xview/icon.h>
#include <xview/cursor.h>
#endif

// Font
class wxFont: public wxbFont
{
 public:
#ifdef wx_motif
  XFontStruct *xFont;
#endif
#ifdef wx_xview
  Xv_Font x_font;
#endif

  wxFont(void);
  wxFont(int PointSize, int Family, int Style, int Weight, Bool underlined = FALSE);
  ~wxFont(void);
};

class wxColourMap: public wxbColourMap
{
 public:
  Colormap cmap;

  wxColourMap(void);
  ~wxColourMap(void);
};

#define wxColorMap wxColourMap

// Pen
class wxPen: public wxbPen
{
 public:
  wxPen(void);
  wxPen(wxColour& col, int width, int style);
  wxPen(char *col, int width, int style);
  ~wxPen(void);

  virtual void SetColour(wxColour& col);
  virtual void SetColour(char *col);
  virtual void SetColour(char r, char g, char b);

  virtual void SetWidth(int width);
  virtual void SetStyle(int style);
};

// Brush
class wxBrush: public wxbBrush
{
 public:
  wxBrush(void);
  wxBrush(wxColour& col, int style);
  wxBrush(char *col, int style);
  ~wxBrush(void);

  void SetColour(wxColour& col);
  void SetColour(char *col);
  void SetColour(char r, char g, char b);

  void SetStyle(int style);
};

// Icon
class wxIcon: public wxbIcon
{
 public:
#ifdef wx_motif
  int iconWidth;
  int iconHeight;
  Pixmap x_pixmap;
#endif
#ifdef wx_xview
  Server_image x_image;
  Icon x_icon;
#endif
  wxIcon(char bits[], int width, int height);
  wxIcon(char *name);
  ~wxIcon(void);
};

// Cursor
class wxCursor: public wxbCursor
{
 public:
#ifdef wx_motif
  Cursor x_cursor;
  Bool use_raw_x_cursor;
#endif
#ifdef wx_xview
  Xv_Cursor x_cursor;
  Bool use_raw_x_cursor;
#endif

  wxCursor(char bits[], int width, int height);
  wxCursor(char *name);
  wxCursor(int cursor_type);
  ~wxCursor(void);
};

// Bitmap
class wxBitmap: public wxbBitmap
{
 public:
  Pixmap x_pixmap;
  Bool freePixmap;

#ifdef wx_xview
  Server_image x_image;
#endif

  wxBitmap(char bits[], int width, int height, int depth = 1);
  wxBitmap(char *name);
  // If depth is omitted, will create a bitmap compatible with the display
  wxBitmap(int width, int height, int depth = -1);
  ~wxBitmap(void);
};

#ifdef wx_x
// X-specific font matching mechanism
class XFontInfo: public wxObject
{
 public:
  int family;
  int style;
  int weight;
  int point_size; // Points in XView, 10ths of a point in Motif
  Bool underlined;
#ifdef wx_xview
  Xv_Font font;
#endif
#ifdef wx_motif
  XFontStruct *font;
#endif
  XFontInfo(int the_family, int the_style, int the_weight, int the_point_size,
             Bool underlined,
#ifdef wx_xview
            Xv_Font the_font);
#endif
#ifdef wx_motif
            XFontStruct *the_font);
#endif
};

class XFontPool: public wxList
{
  XFontInfo *cache;
 public:
  XFontPool(void);
  void AddFont(int family, int style, int weight, int point_size, Bool underlined,
#ifdef wx_xview
               Xv_Font font);
#endif
#ifdef wx_motif
               XFontStruct *font);
#endif
#ifdef wx_xview
  Xv_Font
#endif
#ifdef wx_motif
  XFontStruct *
#endif
    FindFont(int family, int style, int weight, int point_size, Bool underlined);

#ifdef wx_xview
  Xv_Font
#endif
#ifdef wx_motif
  XFontStruct *
#endif
    FindOrCreateFont(int family, int style, int weight, int point_size, Bool underlined, int point_size_to_store, int xres, int yres);

#ifdef wx_xview
  Xv_Font FindNearestFont(int family, int style, int weight, int point_size, Bool underlined, int xres, int yres);
#endif
#ifdef wx_motif
  XFontStruct *FindNearestFont(int family, int style, int weight, int point_size, Bool underlined, int xres, int yres);
#endif
};

extern XFontPool *wxFontPool;
#endif

#endif // wx_gdih
